
# Slot: none_of


holds if none of the expressions hold

URI: [linkml:class_expression_none_of](https://w3id.org/linkml/class_expression_none_of)


## Domain and Range

[ClassExpression](ClassExpression.md) &#8594;  <sub>0..\*</sub> [AnonymousClassExpression](AnonymousClassExpression.md)

## Parents

 *  is_a: [none_of](none_of.md)

## Children


## Used by

 * [AnonymousClassExpression](AnonymousClassExpression.md)
 * [ClassDefinition](ClassDefinition.md)
 * [ClassExpression](ClassExpression.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | sh:not |

